# Generated by Django 3.2.18 on 2023-04-27 12:45

import ambient_toolbox.mixins.models
import ambient_toolbox.mixins.validation
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='MyPermissionModelMixin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'managed': False,
            },
            bases=(ambient_toolbox.mixins.models.PermissionModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ModelWithCleanMixin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            bases=(ambient_toolbox.mixins.validation.CleanOnSaveMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ModelWithSaveWithoutSignalsMixin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.PositiveIntegerField(default=0)),
            ],
            bases=(ambient_toolbox.mixins.models.SaveWithoutSignalsMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ModelWithSelector',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='MyMultipleSignalModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='MySingleSignalModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='ModelWithOneToOneToSelf',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                (
                    'peer',
                    models.OneToOneField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='related_peer',
                        to='testapp.modelwithonetoonetoself',
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name='ModelWithFkToSelf',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                (
                    'parent',
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='children',
                        to='testapp.modelwithfktoself',
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name='ForeignKeyRelatedModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                (
                    'single_signal',
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name='foreign_key_related_models',
                        to='testapp.mysinglesignalmodel',
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name='CommonInfoBasedModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                (
                    'created_at',
                    models.DateTimeField(db_index=True, default=django.utils.timezone.now, verbose_name='Created at'),
                ),
                (
                    'lastmodified_at',
                    models.DateTimeField(
                        db_index=True, default=django.utils.timezone.now, verbose_name='Last modified at'
                    ),
                ),
                ('value', models.PositiveIntegerField(default=0)),
                (
                    'created_by',
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name='testapp_commoninfobasedmodel_created',
                        to=settings.AUTH_USER_MODEL,
                        verbose_name='Created by',
                    ),
                ),
                (
                    'lastmodified_by',
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name='testapp_commoninfobasedmodel_lastmodified',
                        to=settings.AUTH_USER_MODEL,
                        verbose_name='Last modified by',
                    ),
                ),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
